==> wls-plugin-3.0.1-sources.jar: com/xebialabs/deployit/plugin/wls/step/CreateWlsJmsUniformDistributedQueueStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsUniformDistributedQueue;
import com.xebialabs.deployit.plugin.wls.mapper.JmsMapperUtils;

/**
 * Creates a {@link WlsJmsUniformDistributedQueue JMS Uniform Distributed Queue}.
 */
@SuppressWarnings("serial")
public class CreateWlsJmsUniformDistributedQueueStep extends SimpleWlstExecutingStep {
	private static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-jms-uniform-distributed-queue.py";

	public CreateWlsJmsUniformDistributedQueueStep(WlsDomain domain, WlsJmsUniformDistributedQueue distributedQueue, String jmsModuleName) {
		/*
		 * FIXME: this is making the quite strong assumption that the JMS servers of the distributed queue is the same as the set of JMS servers
		 * that are targeted to servers of the cluster that this UDQ is targeted to. 
		 */
		super("Create JMS Uniform Distributed Queue " + distributedQueue + " in domain " + domain, domain, SCRIPT_RESOURCE_PATH, jmsModuleName, 
				JmsMapperUtils.getSubdeploymentName(jmsModuleName, distributedQueue.getJmsServers()), distributedQueue.getName(), distributedQueue.getJndiName());
	}

}

==> wls-plugin-3.0.2-sources.jar: com/xebialabs/deployit/plugin/wls/step/CreateWlsJmsUniformDistributedQueueStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsJmsUniformDistributedQueue;
import com.xebialabs.deployit.plugin.wls.mapper.JmsMapperUtils;

/**
 * Creates a {@link WlsJmsUniformDistributedQueue JMS Uniform Distributed Queue}.
 */
@SuppressWarnings("serial")
public class CreateWlsJmsUniformDistributedQueueStep extends SimpleWlstExecutingStep {
	private static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-jms-uniform-distributed-queue.py";

	public CreateWlsJmsUniformDistributedQueueStep(WlsDomain domain, WlsJmsUniformDistributedQueue distributedQueue, String jmsModuleName) {
		/*
		 * FIXME: this is making the quite strong assumption that the JMS servers of the distributed queue is the same as the set of JMS servers
		 * that are targeted to servers of the cluster that this UDQ is targeted to. 
		 */
		super("Create JMS Uniform Distributed Queue " + distributedQueue + " in domain " + domain, domain, SCRIPT_RESOURCE_PATH, asArguments(jmsModuleName,
				JmsMapperUtils.getSubdeploymentName(jmsModuleName, distributedQueue.getJmsServers()), distributedQueue.getName(), distributedQueue.getJndiName()));
	}

}
